==> zio-aws-apigatewayv2_2.12-7.21.15.4-sources.jar: zio/aws/apigatewayv2/model/DeleteApiMappingRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteApiMappingRequest(
    apiMappingId: __string,
    domainName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest = {
    import DeleteApiMappingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
      .builder()
      .apiMappingId(apiMappingId: java.lang.String)
      .domainName(domainName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteApiMappingRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteApiMappingRequest.wrap(buildAwsValue())
}
object DeleteApiMappingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteApiMappingRequest =
      zio.aws.apigatewayv2.model
        .DeleteApiMappingRequest(apiMappingId, domainName)
    def apiMappingId: __string
    def domainName: __string
    def getApiMappingId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiMappingId)
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
  ) extends zio.aws.apigatewayv2.model.DeleteApiMappingRequest.ReadOnly {
    override val apiMappingId: __string = impl.apiMappingId(): __string
    override val domainName: __string = impl.domainName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
  ): zio.aws.apigatewayv2.model.DeleteApiMappingRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_2.13-5.17.126.2-sources.jar: zio/aws/apigatewayv2/model/DeleteApiMappingRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteApiMappingRequest(
    apiMappingId: __string,
    domainName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest = {
    import DeleteApiMappingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
      .builder()
      .apiMappingId(__string.unwrap(apiMappingId): java.lang.String)
      .domainName(__string.unwrap(domainName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteApiMappingRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteApiMappingRequest.wrap(buildAwsValue())
}
object DeleteApiMappingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteApiMappingRequest =
      zio.aws.apigatewayv2.model
        .DeleteApiMappingRequest(apiMappingId, domainName)
    def apiMappingId: __string
    def domainName: __string
    def getApiMappingId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiMappingId)
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
  ) extends zio.aws.apigatewayv2.model.DeleteApiMappingRequest.ReadOnly {
    override val apiMappingId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiMappingId())
    override val domainName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.domainName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiMappingRequest
  ): zio.aws.apigatewayv2.model.DeleteApiMappingRequest.ReadOnly = new Wrapper(
    impl
  )
}
